16.138. cdist-type__rvm(7) — cdist 6.9.4 documentation

# 16.138. cdist-type__rvm(7)

## 16.138.1. NAME

cdist-type__rvm - Install rvm for a given user

## 16.138.2. DESCRIPTION

RVM is the Ruby enVironment Manager for the Ruby programming language.

## 16.138.3. REQUIRED PARAMETERS

state

  Either "present" or "absent", defaults to "present".

## 16.138.4. EXAMPLES

    # Install rvm for user billie
    __rvm billie --state present

    # Remove rvm
    __rvm billie --state absent

## 16.138.5. SEE ALSO

cdist-type__rvm_gem(7), cdist-type__rvm_gemset(7), cdist-type__rvm_ruby(7)

## 16.138.6. AUTHORS

Evax Software <contact@evax.fr>

## 16.138.7. COPYING

Copyright (C) 2012 Evax Software. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).